package database

import (
	"git.linuxforward.com/byom/byom-onboard/internal/common/models"
	"github.com/google/uuid"
)

func (d *Database) RegisterUser(user *models.User) error {
	// Save registration details to database
	err := d.db.Create(user).Error
	if err != nil {
		return err
	}

	return nil
}

// Add function to verify email token using email and token
func (d *Database) VerifyEmailToken(email, token string) error {
	// Verify the email token
	err := d.db.Where("email = ? AND token = ?", email, token).First(&models.User{}).Error
	if err != nil {
		return err
	}

	return nil
}

func (d *Database) ChangeSubscriptionStatus(email string) error {
	// Change the status of the user to active
	user, err := d.getUserByEmail(email)
	if err != nil {
		return err
	}

	user.ID = uuid.New().String()

	user.Status = true

	err = d.updateUser(user)
	if err != nil {
		return err
	}

	return nil
}

func (d *Database) getUserByEmail(email string) (*models.User, error) {
	var user *models.User
	err := d.db.Where("email = ?", email).First(&user).Error
	if err != nil {
		return nil, err
	}

	return user, nil
}

func (d *Database) updateUser(user *models.User) error {
	err := d.db.Save(user).Error
	if err != nil {
		return err
	}

	return nil
}
